@@ -187,6 +187,13 @@ class BaseKempObject(HttpClient, AccessInfoMixin):
             self.__class__.__name__,
             json.dumps(self.to_dict()))
 
+    def _is_successful_or_raise(self, response):
+        if is_successful(response):
+            data = get_data(response)
+            self.populate_default_attributes(data)
+        else:
+            raise KempTechApiException(get_error_msg(response))
+
     @property
     def access_info(self):
         info = super(BaseKempObject, self).access_info
@@ -199,12 +206,7 @@ class BaseKempObject(HttpClient, AccessInfoMixin):
         else:
             response = self._get(self._API_MOD, self.to_api_dict())
 
-        # pylint: disable=duplicate-code
-        if is_successful(response):
-            data = get_data(response)
-            self.populate_default_attributes(data)
-        else:
-            raise KempTechApiException(get_error_msg(response))
+        self._is_successful_or_raise(response)
 
     def update(self):
         self.save(update=True)
@@ -223,7 +225,7 @@ class BaseKempObject(HttpClient, AccessInfoMixin):
         return send_response(response)
 
     def to_api_dict(self):
-        """returns API related attributes as a dict
+        """Returns API related attributes as a dict
 
         Ignores attributes listed in _api_ignore and also attributes
         beginning with an underscore (_). Also ignore values of None"""
@@ -247,18 +249,16 @@ class BaseKempObject(HttpClient, AccessInfoMixin):
 
     def _get_base_parameters(self):
         """Returns the bare minimum parameters."""
-
         base_parameters = {}
         for parameter in self._API_BASE_PARAMS:
             base_parameters[parameter] = self.__getattribute__(parameter)
-
         return base_parameters
 
-    def populate_default_attributes(self, dictionary):
+    def populate_default_attributes(self, params):
         """Populate object instance with standard defaults"""
-        if self.API_TAG in dictionary.keys():
-            self.populate_default_attributes(dictionary[self.API_TAG])
+        if self.API_TAG in params.keys():
+            self.populate_default_attributes(params[self.API_TAG])
             return
 
         for attribute, tag in self._API_DEFAULT_ATTRIBUTES.items():
-            self.__setattr__(attribute, dictionary.get(tag, None))
+            setattr(self, attribute, params.get(tag, None))
